pub struct LedgerObject {
pub slot_num: i32,
}Expand description
A ledger object identified only by the slot it was cached into.
use xrpl_common_stdlib::objects::LedgerObject;
use xrpl_common_stdlib::objects::traits::LedgerObjectCommonFields;
use xrpl_common_stdlib::sfield;
// Read PriceDataSeries[0].AssetPrice off an Oracle object, which has no typed wrapper.
let price = LedgerObject::new(slot)
.path()
.field(sfield::PriceDataSeries)
.index(0)
.field(sfield::AssetPrice)
.get::<u64>();Fields
slot_num: i32Implementations
Sourceimpl LedgerObject
impl LedgerObject